#!/usr/bin/env node
/********************************************************* {COPYRIGHT-TOP} ***
 * Licensed Materials - Property of IBM
 * 5725-Z22, 5725-Z63, 5725-U33, 5725-Z63
 *
 * (C) Copyright IBM Corporation 2016, 2017
 *
 * All Rights Reserved.
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 ********************************************************** {COPYRIGHT-END} **/
// Node module: apiconnect-cli-policies

var g = require('strong-globalize')();

module.exports = {
  name: 'policies',
  version: require('../package.json').version,
  path: __filename,
  isBuiltin: true,
  topics: getTopics,
};

function getTopics() {
  return [ {
    name: 'policies',
    commands: [
      {
        command: 'clone',
        loginRequired: true,
        helpInfo: g.f('apic_policies_clone_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').policiesClone(opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'delete <name:version>',
        loginRequired: true,
        helpInfo: g.f('apic_policies_delete_help.txt'),
        action: function(nameVersion, opts) {
          return require('./plugin-impl').policiesDelete(nameVersion, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'get <name:version>',
        loginRequired: true,
        helpInfo: g.f('apic_policies_get_help.txt'),
        action: function(nameVersion, opts) {
          return require('./plugin-impl').policiesGet(nameVersion, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
        ],
      },
      {
        command: 'list',
        aliases: [ 'policies' ],
        loginRequired: true,
        helpInfo: g.f('apic_policies_list_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').policiesList(opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs' },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs' },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
          { name: 'all-catalogs', rune: 'C', type: 'boolean' },
          { name: 'all-organizations', rune: 'O', type: 'boolean' },
        ],
      },
      {
        command: 'pull <name:version>',
        loginRequired: true,
        helpInfo: g.f('apic_policies_pull_help.txt'),
        action: function(prodVersion, opts) {
          return require('./plugin-impl').policiesPull(prodVersion, opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
          { name: 'product-only', rune: 'p', type: 'boolean' },
        ],
      },
/*
      {
        command: 'clear',
        loginRequired: true,
        helpInfo: helpInfo('apic_policies_clear_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').policiesClear(opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
          { name: 'confirm', type: 'name' },
        ],
      },
*/
      {
        command: 'publish',
        loginRequired: true,
        helpInfo: g.f('apic_policies_publish_help.txt'),
        action: function(opts) {
          return require('./plugin-impl').policiesPublish(opts);
        },
        options: [
          { name: 'catalog', rune: 'c', type: 'name', default: '$APIC_CONFIG$.catalog.data.catalogs', required: true },
          { name: 'organization', rune: 'o', type: 'name', default: '$APIC_CONFIG$.catalog.data.orgs', required: true },
          { name: 'server', rune: 's', type: 'url', default: '$APIC_CONFIG$.catalog.host', required: true },
          { name: 'directory', type: 'dir' },
        ],
      },
    ],
  },
  ];
};

